@@ -1,6 +1,6 @@
 import collections
 import os
-from typing import Dict, Optional, Set, List
+from typing import Dict, List, Optional
 
 from strictdoc.helpers.sorting import alphanumeric_sort
 
@@ -94,11 +94,6 @@ class Folder(FileOrFolderEntry):
         assert isinstance(parent_folder, Folder)
         self.parent_folder = parent_folder
 
-    def dump(self):
-        print(self)
-        for subfolder in self.subfolder_trees:
-            subfolder.dump()
-
 
 class FileTree:
     def __init__(self, *, root_folder_or_file):
@@ -150,11 +145,11 @@ class FileTree:
 class FileFinder:
     @staticmethod
     def find_files_with_extensions(
-        *, root_path: str, ignored_dirs: List[str], extensions: Set[str]
+        *, root_path: str, ignored_dirs: List[str], extensions: List[str]
     ):
         assert os.path.isdir(root_path)
         assert os.path.isabs(root_path)
-        assert isinstance(extensions, set)
+        assert isinstance(extensions, list), extensions
 
         root_level: int = root_path.count(os.sep)
 
@@ -172,6 +167,7 @@ class FileFinder:
                 if (
                     not d.startswith(".")
                     and not d.startswith("_")
+                    and "tests" not in d
                     and "integration" not in d
                 )
             ]
@@ -189,9 +185,9 @@ class FileFinder:
             def filter_source_files(_files):
                 _source_files = []
                 for file in _files:
-                    _, file_extension = os.path.splitext(file)
-                    if file_extension in extensions:
-                        _source_files.append(file)
+                    for file_extension in extensions:
+                        if file.endswith(file_extension):
+                            _source_files.append(file)
                 return _source_files
 
             files = filter_source_files(files)
