@@ -2,7 +2,7 @@
 // **
 // Place this code right after the opening BODY tag:
 
-// <script>document.body.dataset.state = sessionStorage.getItem('tocState') || 'open';</script>
+// <script>document.body.dataset.toc_state = sessionStorage.getItem('tocState') || 'open';</script>
 
 // This ensures that the status of the sidebar is preserved when the page is reloaded.
 // **
@@ -16,12 +16,12 @@ function switchTOC() {
       ? 'close'
       : 'open'
   ));
-  document.body.dataset.state = sessionStorage.getItem('tocState');
+  document.body.dataset.toc_state = sessionStorage.getItem('tocState');
 }
 
-window.onload = function () {
-  document.body.dataset.state = sessionStorage.getItem('tocState');
-  document.getElementById('layout_toggle').addEventListener('click', () => {
+window.addEventListener("load",function(){
+  document.body.dataset.toc_state = sessionStorage.getItem('tocState');
+  document.getElementById('toc_handler').addEventListener('click', () => {
     switchTOC();
   });
-};
+},false);
