@@ -10,11 +10,36 @@ from strictdoc.export.html.document_type import DocumentType
 
 
 class LinkRenderer:
-    def __init__(self, output_html_root):
-        self.output_html_root = output_html_root
+    def __init__(self, *, root_path, static_path: str):
+        assert isinstance(root_path, str)
+        assert isinstance(static_path, str), static_path
+        assert len(static_path) > 0, static_path
+
+        self.root_path: str = root_path
+        self.static_path: str = (
+            f"{root_path}/{static_path}"
+            if len(root_path) > 0
+            else f"{static_path}"
+        )
         self.local_anchor_cache = {}
         self.req_link_cache = {}
 
+    def render_url(self, url):
+        if len(self.root_path) == 0:
+            return url
+        return self.root_path + "/" + url
+
+    def render_static_url(self, url):
+        static_url = self.static_path + "/" + url
+        return static_url
+
+    # This rarely used helper adds slashes to the import statements within
+    # <script type="module">, for example document_tree.jinja.html.
+    # Otherwise, scripts are not imported correctly.
+    def render_static_url_with_prefix(self, url):
+        static_url = "/" + self.static_path + "/" + url
+        return static_url
+
     def render_local_anchor(self, node):
         if node in self.local_anchor_cache:
             return self.local_anchor_cache[node]
@@ -22,13 +47,16 @@ class LinkRenderer:
         if isinstance(node, Section):
             local_anchor = f"{unique_prefix}-{self._string_to_link(node.title)}"
         elif isinstance(node, Requirement):
-            if node.uid and len(node.uid) > 0:
+            if node.reserved_uid and len(node.reserved_uid) > 0:
                 local_anchor = (
-                    f"{unique_prefix}-{self._string_to_link(node.uid)}"
+                    f"{unique_prefix}-{self._string_to_link(node.reserved_uid)}"
                 )
-            elif node.title and len(node.title) > 0:
+            elif (
+                node.reserved_title is not None and len(node.reserved_title) > 0
+            ):
                 local_anchor = (
-                    f"{unique_prefix}-{self._string_to_link(node.title)}"
+                    f"{unique_prefix}-"
+                    f"{self._string_to_link(node.reserved_title)}"
                 )
             else:
                 # TODO: This is not reliable
@@ -44,9 +72,9 @@ class LinkRenderer:
         context_document: Optional[Document],
         document_type: DocumentType,
     ):
-        assert isinstance(node, (Requirement, Section))
-        assert isinstance(context_document, Document)
-        assert isinstance(document_type, DocumentType)
+        assert isinstance(node, (Requirement, Section)), node
+        assert isinstance(context_document, Document), context_document
+        assert isinstance(document_type, DocumentType), document_type
         local_link = self.render_local_anchor(node)
         if context_document and node.document == context_document:
             return f"#{local_link}"
@@ -87,7 +115,7 @@ class LinkRenderer:
     def render_source_file_link(
         requirement: Requirement, file_reference: FileReference
     ):
-        assert isinstance(file_reference, FileReference)
+        assert isinstance(file_reference, FileReference), file_reference
 
         document_or_none: Optional[
             Document
@@ -100,17 +128,14 @@ class LinkRenderer:
             "/"
             f"_source_files"
             "/"
-            f"{file_reference.path_forward_slashes}.html"
+            f"{file_reference.get_posix_path()}.html"
         )
         return source_file_link
 
     @staticmethod
     def render_source_file_link_from_root(file_reference: FileReference):
         assert isinstance(file_reference, FileReference)
-        source_file_link = (
-            f"_source_files/{file_reference.path_forward_slashes}.html"
-        )
-        return source_file_link
+        return f"_source_files/{file_reference.get_posix_path()}.html"
 
     @staticmethod
     def render_source_file_link_from_root_2(source_file: SourceFile):
@@ -118,7 +143,7 @@ class LinkRenderer:
         source_file_link = (
             "_source_files"
             "/"
-            f"{source_file.in_doctree_source_file_rel_path}.html"
+            f"{source_file.in_doctree_source_file_rel_path_posix}.html"
         )
         return source_file_link
 
@@ -128,9 +153,6 @@ class LinkRenderer:
         source_link: FileReference,
         context_source_file: SourceFile,
     ):
-        assert isinstance(source_link, FileReference)
-        assert len(source_link.path) > 0
-
         def get_root_path_prefix(level):
             if level == 0:
                 return ".."
@@ -140,7 +162,8 @@ class LinkRenderer:
         source_file_link = (
             f"{path_prefix}"
             f"/_source_files"
-            f"/{source_link.path_forward_slashes}.html#{requirement.uid}"
+            f"/{source_link.get_posix_path()}.html"
+            f"#{requirement.reserved_uid}"
         )
         return source_file_link
 
@@ -181,8 +204,8 @@ class LinkRenderer:
         assert isinstance(source_link, FileReference)
         assert isinstance(context_source_file, SourceFile)
         return self.render_requirement_in_source_file_range_link_using_id(
-            requirement.uid,
-            source_link.path_forward_slashes,
+            requirement.reserved_uid,
+            source_link.get_posix_path(),
             context_source_file,
             source_range,
         )
