@@ -6,9 +6,9 @@ def atoi(text):
 
 
 def alphanumeric_sort(text):
-    '''
+    """
     alist.sort(key=natural_keys) sorts in human order
     http://nedbatchelder.com/blog/200712/human_sorting.html
     (See Toothy's implementation in the comments)
-    '''
-    return [ atoi(c) for c in re.split(r'(\d+)', text) ]
\ No newline at end of file
+    """
+    return [atoi(c) for c in re.split(r"(\d+)", text)]
